translate.convert.ical2po.ical2po

Package translate :: Package convert :: Module ical2po :: Class ical2po |
[hide private]
[frames] | no frames]

# Class ical2po

source code

convert a iCal file to a .po file for handling the translation...

Instance Methods | [hide private]
convert_store(self, input_store, duplicatestyle="msgctxt") converts a iCal file to a .po file... | source code
merge_store(self, template_store, input_store, blankmsgstr=False, duplicatestyle="msgctxt") converts two iCal files to a .po file... | source code
convert_unit(self, input_unit, commenttype) Converts a .ini unit to a .po unit. | source code

Method Details | [hide private]

### convert_unit(self, input_unit, commenttype) | source code
Converts a .ini unit to a .po unit. Returns None if empty or not for translation.